
from sugar.chains import  BaseChain

limit = 500
skip = 0
with BaseChain() as chain:
    with chain.web3.batch_requests() as batcher:
        for i in range(0, 3):
            batcher.add(chain.sugar.functions.all(limit, skip))

        result = batcher.execute()
        print(result)
        skip += limit


from typing import Optional

from netmind_sugar.token import Token as S_Token
from dataclasses import dataclass, asdict


@dataclass(frozen=True)
class Token(S_Token):
    wrapped_token_address: Optional[str] = None


@dataclass(frozen=True)
class LiquidityPool:
    address: str
    token0: Token
    token1: Token
    total_supply: int
    reserves: dict
